referrerpolicy=no-referrer-when-downgrade

ActiveEra

Type Alias ActiveEra 

pub type ActiveEra<T> = StorageValue<_GeneratedPrefixForStorageActiveEra<T>, ActiveEraInfo>;
The active era information, it holds index and start.

The active era is the era being currently rewarded. Validator set of this era must be equal to what is RC’s session pallet.

Storage type is [StorageValue] with value type ActiveEraInfo.

Aliased Type

pub struct ActiveEra<T>(/* private fields */);