pub type AreNominatorsSlashable<T: Config> = StorageValue<_GeneratedPrefixForStorageAreNominatorsSlashable<T>, bool, ValueQuery, ConstBool<true>>;Expand description
Whether nominators are slashable or not.
- When set to
true(default), nominators are slashed along with validators and must wait the fullConfig::BondingDurationbefore withdrawing unbonded funds. - When set to
false, nominators are not slashed, and can unbond inConfig::NominatorFastUnbondDurationeras instead of the fullConfig::BondingDuration(see [StakingInterface::nominator_bonding_duration]).
Storage type is [StorageValue] with value type bool.
Aliased Type
pub struct AreNominatorsSlashable<T: Config>(/* private fields */);