referrerpolicy=no-referrer-when-downgrade

ChillInactiveThreshold

Type Alias ChillInactiveThreshold 

pub type ChillInactiveThreshold<T: Config> = StorageValue<_GeneratedPrefixForStorageChillInactiveThreshold<T>, u32, ValueQuery, T::HistoryDepth>;
The number of eras a validator can remain inactive during the last Config::HistoryDepth before being subject to chilling because of inactivity.

This must be less than or equal Config::HistoryDepth and bigger than 1.

Storage type is [StorageValue] with value type u32.

Aliased Type

pub struct ChillInactiveThreshold<T: Config>(/* private fields */);