referrerpolicy=no-referrer-when-downgrade

ErasNominatorsSlashable

Type Alias ErasNominatorsSlashable 

pub type ErasNominatorsSlashable<T: Config> = StorageMap<_GeneratedPrefixForStorageErasNominatorsSlashable<T>, Twox64Concat, EraIndex, bool, OptionQuery>;
Per-era snapshot of whether nominators are slashable.

This is copied from AreNominatorsSlashable at the start of each era. When processing offences, we use the value from this storage for the offence era to ensure that the slashing rules at the time of the offence are applied, not the current rules.

If an entry does not exist for an era, nominators are assumed to be slashable (default).

Storage type is [StorageMap] with key type EraIndex and value type bool.

Aliased Type

pub struct ErasNominatorsSlashable<T: Config>(/* private fields */);