referrerpolicy=no-referrer-when-downgrade

VoterSnapshotStatus

Type Alias VoterSnapshotStatus 

pub type VoterSnapshotStatus<T: Config> = StorageValue<_GeneratedPrefixForStorageVoterSnapshotStatus<T>, SnapshotStatus<T::AccountId>, ValueQuery>;
Voter snapshot progress status.

If the status is Ongoing, it keeps a cursor of the last voter retrieved to proceed when creating the next snapshot page.

Storage type is [StorageValue] with value type SnapshotStatus < T :: AccountId >.

Aliased Type

pub struct VoterSnapshotStatus<T: Config>(/* private fields */);