pub type ErasValidatorReward<T: Config> = StorageMap<_GeneratedPrefixForStorageErasValidatorReward<T>, Twox64Concat, EraIndex, BalanceOf<T>>;Expand description
The total staker reward budget for each era within Config::HistoryDepth.
Set at era finalization:
- in non-minting mode this is the snapshot of the era pot balance before any payouts.
- in legacy mode it comes from
EraPayout, with rewards minted on the fly.
Storage type is [StorageMap] with key type EraIndex and value type BalanceOf < T >.
Aliased Type
pub struct ErasValidatorReward<T: Config>(/* private fields */);